Files for interfacing Genten with Matlab using the
[Tensor Toolbox](http://www.tensortoolbox.org/).

Included are MEX files for calling Genten from Matlab, using Tensor
Toolbox sparse tensor data structures.  Also included is a new sparse
tensor format (sptensor_gt) that doesn't require any copying of tensor
data when calling Genten from Matlab.
